==> realestate-supervise-common-1.1.0-20230309.084025-25-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq3Ls.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 建筑物区分所有权业主共有部分属性
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq3_ls"
)
public class BaFdcq3Ls implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String jgzwbh;

    @XmlAttribute
    private String jgzwmc;

    @XmlAttribute
    private int jgzwsl;

    @XmlAttribute
    private String jgzwmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String djlx;

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getJgzwbh() {
        return jgzwbh;
    }

    public String getJgzwmc() {
        return jgzwmc;
    }

    public int getJgzwsl() {
        return jgzwsl;
    }

    public String getJgzwmj() {
        return jgzwmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setJgzwbh(String jgzwbh) {
        this.jgzwbh = jgzwbh;
    }

    public void setJgzwmc(String jgzwmc) {
        this.jgzwmc = jgzwmc;
    }

    public void setJgzwsl(int jgzwsl) {
        this.jgzwsl = jgzwsl;
    }

    public void setJgzwmj(String jgzwmj) {
        this.jgzwmj = jgzwmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq3Ls.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.sqlx;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 建筑物区分所有权业主共有部分属性
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq3_ls"
)
public class BaFdcq3Ls implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String jgzwbh;

    @XmlAttribute
    private String jgzwmc;

    @XmlAttribute
    private int jgzwsl;

    @XmlAttribute
    private String jgzwmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String djlx;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getJgzwbh() {
        return jgzwbh;
    }

    public String getJgzwmc() {
        return jgzwmc;
    }

    public int getJgzwsl() {
        return jgzwsl;
    }

    public String getJgzwmj() {
        return jgzwmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setJgzwbh(String jgzwbh) {
        this.jgzwbh = jgzwbh;
    }

    public void setJgzwmc(String jgzwmc) {
        this.jgzwmc = jgzwmc;
    }

    public void setJgzwsl(int jgzwsl) {
        this.jgzwsl = jgzwsl;
    }

    public void setJgzwmj(String jgzwmj) {
        this.jgzwmj = jgzwmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}
